/* GomProperty.c generated by valac 0.34.6, the Vala compiler
 * generated from GomProperty.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_GOM_PROPERTY (gxml_gom_property_get_type ())
#define GXML_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomProperty))
#define GXML_IS_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_PROPERTY))
#define GXML_GOM_PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomPropertyIface))

typedef struct _GXmlGomProperty GXmlGomProperty;
typedef struct _GXmlGomPropertyIface GXmlGomPropertyIface;

#define GXML_TYPE_GOM_BASE_PROPERTY (gxml_gom_base_property_get_type ())
#define GXML_GOM_BASE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_BASE_PROPERTY, GXmlGomBaseProperty))
#define GXML_GOM_BASE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_BASE_PROPERTY, GXmlGomBasePropertyClass))
#define GXML_IS_GOM_BASE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_BASE_PROPERTY))
#define GXML_IS_GOM_BASE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_BASE_PROPERTY))
#define GXML_GOM_BASE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_BASE_PROPERTY, GXmlGomBasePropertyClass))

typedef struct _GXmlGomBaseProperty GXmlGomBaseProperty;
typedef struct _GXmlGomBasePropertyClass GXmlGomBasePropertyClass;
typedef struct _GXmlGomBasePropertyPrivate GXmlGomBasePropertyPrivate;

#define GXML_TYPE_GOM_STRING (gxml_gom_string_get_type ())
#define GXML_GOM_STRING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_STRING, GXmlGomString))
#define GXML_GOM_STRING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_STRING, GXmlGomStringClass))
#define GXML_IS_GOM_STRING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_STRING))
#define GXML_IS_GOM_STRING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_STRING))
#define GXML_GOM_STRING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_STRING, GXmlGomStringClass))

typedef struct _GXmlGomString GXmlGomString;
typedef struct _GXmlGomStringClass GXmlGomStringClass;
typedef struct _GXmlGomStringPrivate GXmlGomStringPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_GOM_ARRAY_STRING (gxml_gom_array_string_get_type ())
#define GXML_GOM_ARRAY_STRING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ARRAY_STRING, GXmlGomArrayString))
#define GXML_GOM_ARRAY_STRING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ARRAY_STRING, GXmlGomArrayStringClass))
#define GXML_IS_GOM_ARRAY_STRING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ARRAY_STRING))
#define GXML_IS_GOM_ARRAY_STRING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ARRAY_STRING))
#define GXML_GOM_ARRAY_STRING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ARRAY_STRING, GXmlGomArrayStringClass))

typedef struct _GXmlGomArrayString GXmlGomArrayString;
typedef struct _GXmlGomArrayStringClass GXmlGomArrayStringClass;
typedef struct _GXmlGomArrayStringPrivate GXmlGomArrayStringPrivate;

#define GXML_TYPE_GOM_XSD_ARRAY_STRING (gxml_gom_xsd_array_string_get_type ())
#define GXML_GOM_XSD_ARRAY_STRING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_ARRAY_STRING, GXmlGomXsdArrayString))
#define GXML_GOM_XSD_ARRAY_STRING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_ARRAY_STRING, GXmlGomXsdArrayStringClass))
#define GXML_IS_GOM_XSD_ARRAY_STRING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_ARRAY_STRING))
#define GXML_IS_GOM_XSD_ARRAY_STRING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_ARRAY_STRING))
#define GXML_GOM_XSD_ARRAY_STRING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_ARRAY_STRING, GXmlGomXsdArrayStringClass))

typedef struct _GXmlGomXsdArrayString GXmlGomXsdArrayString;
typedef struct _GXmlGomXsdArrayStringClass GXmlGomXsdArrayStringClass;
typedef struct _GXmlGomXsdArrayStringPrivate GXmlGomXsdArrayStringPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;

#define GXML_TYPE_GOM_XSD_SCHEMA (gxml_gom_xsd_schema_get_type ())
#define GXML_GOM_XSD_SCHEMA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_SCHEMA, GXmlGomXsdSchema))
#define GXML_GOM_XSD_SCHEMA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_SCHEMA, GXmlGomXsdSchemaClass))
#define GXML_IS_GOM_XSD_SCHEMA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_SCHEMA))
#define GXML_IS_GOM_XSD_SCHEMA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_SCHEMA))
#define GXML_GOM_XSD_SCHEMA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_SCHEMA, GXmlGomXsdSchemaClass))

typedef struct _GXmlGomXsdSchema GXmlGomXsdSchema;
typedef struct _GXmlGomXsdSchemaClass GXmlGomXsdSchemaClass;

#define GXML_TYPE_BASE_COLLECTION (gxml_base_collection_get_type ())
#define GXML_BASE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_BASE_COLLECTION, GXmlBaseCollection))
#define GXML_BASE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_BASE_COLLECTION, GXmlBaseCollectionClass))
#define GXML_IS_BASE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_BASE_COLLECTION))
#define GXML_IS_BASE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_BASE_COLLECTION))
#define GXML_BASE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_BASE_COLLECTION, GXmlBaseCollectionClass))

typedef struct _GXmlBaseCollection GXmlBaseCollection;
typedef struct _GXmlBaseCollectionClass GXmlBaseCollectionClass;

#define GXML_TYPE_GOM_ARRAY_LIST (gxml_gom_array_list_get_type ())
#define GXML_GOM_ARRAY_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ARRAY_LIST, GXmlGomArrayList))
#define GXML_GOM_ARRAY_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ARRAY_LIST, GXmlGomArrayListClass))
#define GXML_IS_GOM_ARRAY_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ARRAY_LIST))
#define GXML_IS_GOM_ARRAY_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ARRAY_LIST))
#define GXML_GOM_ARRAY_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ARRAY_LIST, GXmlGomArrayListClass))

typedef struct _GXmlGomArrayList GXmlGomArrayList;
typedef struct _GXmlGomArrayListClass GXmlGomArrayListClass;

#define GXML_TYPE_GOM_XSD_LIST (gxml_gom_xsd_list_get_type ())
#define GXML_GOM_XSD_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_LIST, GXmlGomXsdList))
#define GXML_GOM_XSD_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_LIST, GXmlGomXsdListClass))
#define GXML_IS_GOM_XSD_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_LIST))
#define GXML_IS_GOM_XSD_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_LIST))
#define GXML_GOM_XSD_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_LIST, GXmlGomXsdListClass))

typedef struct _GXmlGomXsdList GXmlGomXsdList;
typedef struct _GXmlGomXsdListClass GXmlGomXsdListClass;

#define GXML_TYPE_GOM_XSD_LIST_SIMPLE_TYPES (gxml_gom_xsd_list_simple_types_get_type ())
#define GXML_GOM_XSD_LIST_SIMPLE_TYPES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_LIST_SIMPLE_TYPES, GXmlGomXsdListSimpleTypes))
#define GXML_GOM_XSD_LIST_SIMPLE_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_LIST_SIMPLE_TYPES, GXmlGomXsdListSimpleTypesClass))
#define GXML_IS_GOM_XSD_LIST_SIMPLE_TYPES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_LIST_SIMPLE_TYPES))
#define GXML_IS_GOM_XSD_LIST_SIMPLE_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_LIST_SIMPLE_TYPES))
#define GXML_GOM_XSD_LIST_SIMPLE_TYPES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_LIST_SIMPLE_TYPES, GXmlGomXsdListSimpleTypesClass))

typedef struct _GXmlGomXsdListSimpleTypes GXmlGomXsdListSimpleTypes;
typedef struct _GXmlGomXsdListSimpleTypesClass GXmlGomXsdListSimpleTypesClass;

#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_GOM_COLLECTION (gxml_gom_collection_get_type ())
#define GXML_GOM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_COLLECTION, GXmlGomCollection))
#define GXML_IS_GOM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_COLLECTION))
#define GXML_GOM_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_COLLECTION, GXmlGomCollectionIface))

typedef struct _GXmlGomCollection GXmlGomCollection;
typedef struct _GXmlGomCollectionIface GXmlGomCollectionIface;

#define GXML_TYPE_GOM_XSD_SIMPLE_TYPE (gxml_gom_xsd_simple_type_get_type ())
#define GXML_GOM_XSD_SIMPLE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_SIMPLE_TYPE, GXmlGomXsdSimpleType))
#define GXML_GOM_XSD_SIMPLE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_SIMPLE_TYPE, GXmlGomXsdSimpleTypeClass))
#define GXML_IS_GOM_XSD_SIMPLE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_SIMPLE_TYPE))
#define GXML_IS_GOM_XSD_SIMPLE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_SIMPLE_TYPE))
#define GXML_GOM_XSD_SIMPLE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_SIMPLE_TYPE, GXmlGomXsdSimpleTypeClass))

typedef struct _GXmlGomXsdSimpleType GXmlGomXsdSimpleType;
typedef struct _GXmlGomXsdSimpleTypeClass GXmlGomXsdSimpleTypeClass;

#define GXML_TYPE_GOM_XSD_TYPE_DEFINITION (gxml_gom_xsd_type_definition_get_type ())
#define GXML_GOM_XSD_TYPE_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_TYPE_DEFINITION, GXmlGomXsdTypeDefinition))
#define GXML_GOM_XSD_TYPE_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_TYPE_DEFINITION, GXmlGomXsdTypeDefinitionClass))
#define GXML_IS_GOM_XSD_TYPE_DEFINITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_TYPE_DEFINITION))
#define GXML_IS_GOM_XSD_TYPE_DEFINITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_TYPE_DEFINITION))
#define GXML_GOM_XSD_TYPE_DEFINITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_TYPE_DEFINITION, GXmlGomXsdTypeDefinitionClass))

typedef struct _GXmlGomXsdTypeDefinition GXmlGomXsdTypeDefinition;
typedef struct _GXmlGomXsdTypeDefinitionClass GXmlGomXsdTypeDefinitionClass;

#define GXML_TYPE_GOM_XSD_TYPE_RESTRICTION (gxml_gom_xsd_type_restriction_get_type ())
#define GXML_GOM_XSD_TYPE_RESTRICTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION, GXmlGomXsdTypeRestriction))
#define GXML_GOM_XSD_TYPE_RESTRICTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION, GXmlGomXsdTypeRestrictionClass))
#define GXML_IS_GOM_XSD_TYPE_RESTRICTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION))
#define GXML_IS_GOM_XSD_TYPE_RESTRICTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION))
#define GXML_GOM_XSD_TYPE_RESTRICTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION, GXmlGomXsdTypeRestrictionClass))

typedef struct _GXmlGomXsdTypeRestriction GXmlGomXsdTypeRestriction;
typedef struct _GXmlGomXsdTypeRestrictionClass GXmlGomXsdTypeRestrictionClass;

#define GXML_TYPE_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS (gxml_gom_xsd_list_type_restriction_enumerations_get_type ())
#define GXML_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS, GXmlGomXsdListTypeRestrictionEnumerations))
#define GXML_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS, GXmlGomXsdListTypeRestrictionEnumerationsClass))
#define GXML_IS_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS))
#define GXML_IS_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS))
#define GXML_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_LIST_TYPE_RESTRICTION_ENUMERATIONS, GXmlGomXsdListTypeRestrictionEnumerationsClass))

typedef struct _GXmlGomXsdListTypeRestrictionEnumerations GXmlGomXsdListTypeRestrictionEnumerations;
typedef struct _GXmlGomXsdListTypeRestrictionEnumerationsClass GXmlGomXsdListTypeRestrictionEnumerationsClass;

#define GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_DEF (gxml_gom_xsd_type_restriction_def_get_type ())
#define GXML_GOM_XSD_TYPE_RESTRICTION_DEF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_DEF, GXmlGomXsdTypeRestrictionDef))
#define GXML_GOM_XSD_TYPE_RESTRICTION_DEF_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_DEF, GXmlGomXsdTypeRestrictionDefClass))
#define GXML_IS_GOM_XSD_TYPE_RESTRICTION_DEF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_DEF))
#define GXML_IS_GOM_XSD_TYPE_RESTRICTION_DEF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_DEF))
#define GXML_GOM_XSD_TYPE_RESTRICTION_DEF_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_DEF, GXmlGomXsdTypeRestrictionDefClass))

typedef struct _GXmlGomXsdTypeRestrictionDef GXmlGomXsdTypeRestrictionDef;
typedef struct _GXmlGomXsdTypeRestrictionDefClass GXmlGomXsdTypeRestrictionDefClass;

#define GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION (gxml_gom_xsd_type_restriction_enumeration_get_type ())
#define GXML_GOM_XSD_TYPE_RESTRICTION_ENUMERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION, GXmlGomXsdTypeRestrictionEnumeration))
#define GXML_GOM_XSD_TYPE_RESTRICTION_ENUMERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION, GXmlGomXsdTypeRestrictionEnumerationClass))
#define GXML_IS_GOM_XSD_TYPE_RESTRICTION_ENUMERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION))
#define GXML_IS_GOM_XSD_TYPE_RESTRICTION_ENUMERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION))
#define GXML_GOM_XSD_TYPE_RESTRICTION_ENUMERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION, GXmlGomXsdTypeRestrictionEnumerationClass))

typedef struct _GXmlGomXsdTypeRestrictionEnumeration GXmlGomXsdTypeRestrictionEnumeration;
typedef struct _GXmlGomXsdTypeRestrictionEnumerationClass GXmlGomXsdTypeRestrictionEnumerationClass;

#define GXML_TYPE_GOM_DOUBLE (gxml_gom_double_get_type ())
#define GXML_GOM_DOUBLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOUBLE, GXmlGomDouble))
#define GXML_GOM_DOUBLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOUBLE, GXmlGomDoubleClass))
#define GXML_IS_GOM_DOUBLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOUBLE))
#define GXML_IS_GOM_DOUBLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOUBLE))
#define GXML_GOM_DOUBLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOUBLE, GXmlGomDoubleClass))

typedef struct _GXmlGomDouble GXmlGomDouble;
typedef struct _GXmlGomDoubleClass GXmlGomDoubleClass;
typedef struct _GXmlGomDoublePrivate GXmlGomDoublePrivate;

#define GXML_TYPE_GOM_FLOAT (gxml_gom_float_get_type ())
#define GXML_GOM_FLOAT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_FLOAT, GXmlGomFloat))
#define GXML_GOM_FLOAT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_FLOAT, GXmlGomFloatClass))
#define GXML_IS_GOM_FLOAT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_FLOAT))
#define GXML_IS_GOM_FLOAT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_FLOAT))
#define GXML_GOM_FLOAT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_FLOAT, GXmlGomFloatClass))

typedef struct _GXmlGomFloat GXmlGomFloat;
typedef struct _GXmlGomFloatClass GXmlGomFloatClass;
typedef struct _GXmlGomFloatPrivate GXmlGomFloatPrivate;

#define GXML_TYPE_GOM_INT (gxml_gom_int_get_type ())
#define GXML_GOM_INT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_INT, GXmlGomInt))
#define GXML_GOM_INT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_INT, GXmlGomIntClass))
#define GXML_IS_GOM_INT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_INT))
#define GXML_IS_GOM_INT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_INT))
#define GXML_GOM_INT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_INT, GXmlGomIntClass))

typedef struct _GXmlGomInt GXmlGomInt;
typedef struct _GXmlGomIntClass GXmlGomIntClass;
typedef struct _GXmlGomIntPrivate GXmlGomIntPrivate;

#define GXML_TYPE_GOM_BOOLEAN (gxml_gom_boolean_get_type ())
#define GXML_GOM_BOOLEAN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_BOOLEAN, GXmlGomBoolean))
#define GXML_GOM_BOOLEAN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_BOOLEAN, GXmlGomBooleanClass))
#define GXML_IS_GOM_BOOLEAN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_BOOLEAN))
#define GXML_IS_GOM_BOOLEAN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_BOOLEAN))
#define GXML_GOM_BOOLEAN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_BOOLEAN, GXmlGomBooleanClass))

typedef struct _GXmlGomBoolean GXmlGomBoolean;
typedef struct _GXmlGomBooleanClass GXmlGomBooleanClass;
typedef struct _GXmlGomBooleanPrivate GXmlGomBooleanPrivate;

#define GXML_TYPE_GOM_ENUM (gxml_gom_enum_get_type ())
#define GXML_GOM_ENUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ENUM, GXmlGomEnum))
#define GXML_GOM_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ENUM, GXmlGomEnumClass))
#define GXML_IS_GOM_ENUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ENUM))
#define GXML_IS_GOM_ENUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ENUM))
#define GXML_GOM_ENUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ENUM, GXmlGomEnumClass))

typedef struct _GXmlGomEnum GXmlGomEnum;
typedef struct _GXmlGomEnumClass GXmlGomEnumClass;
typedef struct _GXmlGomEnumPrivate GXmlGomEnumPrivate;

#define GXML_TYPE_GOM_DATE (gxml_gom_date_get_type ())
#define GXML_GOM_DATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DATE, GXmlGomDate))
#define GXML_GOM_DATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DATE, GXmlGomDateClass))
#define GXML_IS_GOM_DATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DATE))
#define GXML_IS_GOM_DATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DATE))
#define GXML_GOM_DATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DATE, GXmlGomDateClass))

typedef struct _GXmlGomDate GXmlGomDate;
typedef struct _GXmlGomDateClass GXmlGomDateClass;
typedef struct _GXmlGomDatePrivate GXmlGomDatePrivate;

#define GXML_TYPE_GOM_DATE_TIME (gxml_gom_date_time_get_type ())
#define GXML_GOM_DATE_TIME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTime))
#define GXML_GOM_DATE_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTimeClass))
#define GXML_IS_GOM_DATE_TIME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DATE_TIME))
#define GXML_IS_GOM_DATE_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DATE_TIME))
#define GXML_GOM_DATE_TIME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTimeClass))

typedef struct _GXmlGomDateTime GXmlGomDateTime;
typedef struct _GXmlGomDateTimeClass GXmlGomDateTimeClass;
typedef struct _GXmlGomDateTimePrivate GXmlGomDateTimePrivate;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

struct _GXmlGomPropertyIface {
	GTypeInterface parent_iface;
	gboolean (*validate_value) (GXmlGomProperty* self, const gchar* val);
	gchar* (*get_value) (GXmlGomProperty* self);
	void (*set_value) (GXmlGomProperty* self, const gchar* value);
};

struct _GXmlGomBaseProperty {
	GObject parent_instance;
	GXmlGomBasePropertyPrivate * priv;
};

struct _GXmlGomBasePropertyClass {
	GObjectClass parent_class;
	gboolean (*validate_value) (GXmlGomBaseProperty* self, const gchar* val);
	gchar* (*get_value) (GXmlGomBaseProperty* self);
	void (*set_value) (GXmlGomBaseProperty* self, const gchar* value);
};

struct _GXmlGomString {
	GXmlGomBaseProperty parent_instance;
	GXmlGomStringPrivate * priv;
	gchar* _value;
};

struct _GXmlGomStringClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomArrayString {
	GXmlGomBaseProperty parent_instance;
	GXmlGomArrayStringPrivate * priv;
	gchar* _value;
	gchar** _values;
	gint _values_length1;
};

struct _GXmlGomArrayStringClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomXsdArrayString {
	GXmlGomArrayString parent_instance;
	GXmlGomXsdArrayStringPrivate * priv;
	GFile* _source;
	gchar* _simple_type;
};

struct _GXmlGomXsdArrayStringClass {
	GXmlGomArrayStringClass parent_class;
};

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlGomCollectionIface {
	GTypeInterface parent_iface;
	void (*search) (GXmlGomCollection* self, GError** error);
	GXmlDomElement* (*get_item) (GXmlGomCollection* self, gint index, GError** error);
	void (*append) (GXmlGomCollection* self, GXmlDomElement* node, GError** error);
	void (*initialize) (GXmlGomCollection* self, GType t, GError** error);
	GXmlGomElement* (*create_item) (GXmlGomCollection* self);
	gboolean (*validate_append) (GXmlGomCollection* self, gint index, GXmlDomElement* element, GError** error);
	GQueue* (*get_nodes_index) (GXmlGomCollection* self);
	GXmlGomElement* (*get_element) (GXmlGomCollection* self);
	void (*set_element) (GXmlGomCollection* self, GXmlGomElement* value);
	const gchar* (*get_items_name) (GXmlGomCollection* self);
	GType (*get_items_type) (GXmlGomCollection* self);
	void (*set_items_type) (GXmlGomCollection* self, GType value);
	gint (*get_length) (GXmlGomCollection* self);
};

struct _GXmlGomDouble {
	GXmlGomBaseProperty parent_instance;
	GXmlGomDoublePrivate * priv;
	gdouble _value;
};

struct _GXmlGomDoubleClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomDoublePrivate {
	guint _decimals;
};

struct _GXmlGomFloat {
	GXmlGomDouble parent_instance;
	GXmlGomFloatPrivate * priv;
};

struct _GXmlGomFloatClass {
	GXmlGomDoubleClass parent_class;
};

struct _GXmlGomInt {
	GXmlGomBaseProperty parent_instance;
	GXmlGomIntPrivate * priv;
	gint _value;
};

struct _GXmlGomIntClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomBoolean {
	GXmlGomBaseProperty parent_instance;
	GXmlGomBooleanPrivate * priv;
	gboolean _value;
};

struct _GXmlGomBooleanClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomEnum {
	GXmlGomBaseProperty parent_instance;
	GXmlGomEnumPrivate * priv;
	gint _value;
	GType _enum_type;
};

struct _GXmlGomEnumClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomDate {
	GXmlGomBaseProperty parent_instance;
	GXmlGomDatePrivate * priv;
	GDate _value;
};

struct _GXmlGomDateClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomDateTime {
	GXmlGomBaseProperty parent_instance;
	GXmlGomDateTimePrivate * priv;
	GDateTime* _value;
};

struct _GXmlGomDateTimeClass {
	GXmlGomBasePropertyClass parent_class;
};

struct _GXmlGomDateTimePrivate {
	gchar* _format;
};


static gpointer gxml_gom_base_property_parent_class = NULL;
static GXmlGomPropertyIface* gxml_gom_base_property_gxml_gom_property_parent_iface = NULL;
static gpointer gxml_gom_string_parent_class = NULL;
static gpointer gxml_gom_array_string_parent_class = NULL;
static gpointer gxml_gom_xsd_array_string_parent_class = NULL;
static gpointer gxml_gom_double_parent_class = NULL;
static gpointer gxml_gom_float_parent_class = NULL;
static gpointer gxml_gom_int_parent_class = NULL;
static gpointer gxml_gom_boolean_parent_class = NULL;
static gpointer gxml_gom_enum_parent_class = NULL;
static gpointer gxml_gom_date_parent_class = NULL;
static gpointer gxml_gom_date_time_parent_class = NULL;

GType gxml_gom_property_get_type (void) G_GNUC_CONST;
gboolean gxml_gom_property_validate_value (GXmlGomProperty* self, const gchar* val);
gchar* gxml_gom_property_get_value (GXmlGomProperty* self);
void gxml_gom_property_set_value (GXmlGomProperty* self, const gchar* value);
GType gxml_gom_base_property_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_BASE_PROPERTY_DUMMY_PROPERTY,
	GXML_GOM_BASE_PROPERTY_VALUE
};
gboolean gxml_gom_base_property_validate_value (GXmlGomBaseProperty* self, const gchar* val);
static gboolean gxml_gom_base_property_real_validate_value (GXmlGomBaseProperty* self, const gchar* val);
GXmlGomBaseProperty* gxml_gom_base_property_construct (GType object_type);
gchar* gxml_gom_base_property_get_value (GXmlGomBaseProperty* self);
void gxml_gom_base_property_set_value (GXmlGomBaseProperty* self, const gchar* value);
static void _vala_gxml_gom_base_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_base_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_string_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_STRING_DUMMY_PROPERTY,
	GXML_GOM_STRING_VALUE
};
GXmlGomString* gxml_gom_string_new (void);
GXmlGomString* gxml_gom_string_construct (GType object_type);
static void gxml_gom_string_finalize (GObject* obj);
static void _vala_gxml_gom_string_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_string_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_array_string_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_ARRAY_STRING_DUMMY_PROPERTY,
	GXML_GOM_ARRAY_STRING_VALUE
};
gchar** gxml_gom_array_string_get_values (GXmlGomArrayString* self, int* result_length1);
void gxml_gom_array_string_initialize_strings (GXmlGomArrayString* self, gchar** strs, int strs_length1);
static gchar** _vala_array_dup9 (gchar** self, int length);
gboolean gxml_gom_array_string_is_valid_value (GXmlGomArrayString* self);
void gxml_gom_array_string_select (GXmlGomArrayString* self, gint index);
gboolean gxml_gom_array_string_search (GXmlGomArrayString* self, const gchar* str);
GXmlGomArrayString* gxml_gom_array_string_new (void);
GXmlGomArrayString* gxml_gom_array_string_construct (GType object_type);
static void gxml_gom_array_string_finalize (GObject* obj);
static void _vala_gxml_gom_array_string_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_array_string_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_xsd_array_string_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_XSD_ARRAY_STRING_DUMMY_PROPERTY,
	GXML_GOM_XSD_ARRAY_STRING_SIMPLE_TYPE,
	GXML_GOM_XSD_ARRAY_STRING_SOURCE
};
void gxml_gom_xsd_array_string_load (GXmlGomXsdArrayString* self, GError** error);
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_xsd_schema_get_type (void) G_GNUC_CONST;
GXmlGomXsdSchema* gxml_gom_xsd_schema_new (void);
GXmlGomXsdSchema* gxml_gom_xsd_schema_construct (GType object_type);
void gxml_gom_element_read_from_file (GXmlGomElement* self, GFile* f, GCancellable* cancellable, GError** error);
GType gxml_base_collection_get_type (void) G_GNUC_CONST;
GType gxml_gom_array_list_get_type (void) G_GNUC_CONST;
GType gxml_gom_xsd_list_get_type (void) G_GNUC_CONST;
GType gxml_gom_xsd_list_simple_types_get_type (void) G_GNUC_CONST;
GXmlGomXsdListSimpleTypes* gxml_gom_xsd_schema_get_simple_type_definitions (GXmlGomXsdSchema* self);
gint gxml_gom_xsd_list_get_length (GXmlGomXsdList* self);
GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_collection_get_type (void) G_GNUC_CONST;
GXmlDomElement* gxml_gom_collection_get_item (GXmlGomCollection* self, gint index, GError** error);
GType gxml_gom_xsd_simple_type_get_type (void) G_GNUC_CONST;
const gchar* gxml_gom_xsd_simple_type_get_name (GXmlGomXsdSimpleType* self);
GType gxml_gom_xsd_type_definition_get_type (void) G_GNUC_CONST;
GType gxml_gom_xsd_type_restriction_get_type (void) G_GNUC_CONST;
GXmlGomXsdTypeRestriction* gxml_gom_xsd_simple_type_get_restriction (GXmlGomXsdSimpleType* self);
GType gxml_gom_xsd_list_type_restriction_enumerations_get_type (void) G_GNUC_CONST;
GXmlGomXsdListTypeRestrictionEnumerations* gxml_gom_xsd_type_restriction_get_enumerations (GXmlGomXsdTypeRestriction* self);
GType gxml_gom_xsd_type_restriction_def_get_type (void) G_GNUC_CONST;
GType gxml_gom_xsd_type_restriction_enumeration_get_type (void) G_GNUC_CONST;
const gchar* gxml_gom_xsd_type_restriction_enumeration_get_value (GXmlGomXsdTypeRestrictionEnumeration* self);
static void _vala_array_add10 (gchar*** array, int* length, int* size, gchar* value);
static gchar** _vala_array_dup10 (gchar** self, int length);
GXmlGomXsdArrayString* gxml_gom_xsd_array_string_new (void);
GXmlGomXsdArrayString* gxml_gom_xsd_array_string_construct (GType object_type);
const gchar* gxml_gom_xsd_array_string_get_simple_type (GXmlGomXsdArrayString* self);
void gxml_gom_xsd_array_string_set_simple_type (GXmlGomXsdArrayString* self, const gchar* value);
GFile* gxml_gom_xsd_array_string_get_source (GXmlGomXsdArrayString* self);
void gxml_gom_xsd_array_string_set_source (GXmlGomXsdArrayString* self, GFile* value);
static void gxml_gom_xsd_array_string_finalize (GObject* obj);
static void _vala_gxml_gom_xsd_array_string_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_xsd_array_string_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_double_get_type (void) G_GNUC_CONST;
#define GXML_GOM_DOUBLE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_TYPE_GOM_DOUBLE, GXmlGomDoublePrivate))
enum  {
	GXML_GOM_DOUBLE_DUMMY_PROPERTY,
	GXML_GOM_DOUBLE_VALUE,
	GXML_GOM_DOUBLE_DECIMALS
};
gdouble gxml_gom_double_get_double (GXmlGomDouble* self);
void gxml_gom_double_set_double (GXmlGomDouble* self, gdouble value);
GXmlGomDouble* gxml_gom_double_new (void);
GXmlGomDouble* gxml_gom_double_construct (GType object_type);
guint gxml_gom_double_get_decimals (GXmlGomDouble* self);
void gxml_gom_double_set_decimals (GXmlGomDouble* self, guint value);
static void gxml_gom_double_finalize (GObject* obj);
static void _vala_gxml_gom_double_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_double_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_float_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_FLOAT_DUMMY_PROPERTY
};
gfloat gxml_gom_float_get_float (GXmlGomFloat* self);
void gxml_gom_float_set_float (GXmlGomFloat* self, gfloat value);
GXmlGomFloat* gxml_gom_float_new (void);
GXmlGomFloat* gxml_gom_float_construct (GType object_type);
GType gxml_gom_int_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_INT_DUMMY_PROPERTY,
	GXML_GOM_INT_VALUE
};
gint gxml_gom_int_get_integer (GXmlGomInt* self);
void gxml_gom_int_set_integer (GXmlGomInt* self, gint value);
GXmlGomInt* gxml_gom_int_new (void);
GXmlGomInt* gxml_gom_int_construct (GType object_type);
static void gxml_gom_int_finalize (GObject* obj);
static void _vala_gxml_gom_int_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_int_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_boolean_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_BOOLEAN_DUMMY_PROPERTY,
	GXML_GOM_BOOLEAN_VALUE
};
gboolean gxml_gom_boolean_get_boolean (GXmlGomBoolean* self);
void gxml_gom_boolean_set_boolean (GXmlGomBoolean* self, gboolean value);
GXmlGomBoolean* gxml_gom_boolean_new (void);
GXmlGomBoolean* gxml_gom_boolean_construct (GType object_type);
static void gxml_gom_boolean_finalize (GObject* obj);
static void _vala_gxml_gom_boolean_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_boolean_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_enum_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_ENUM_DUMMY_PROPERTY,
	GXML_GOM_ENUM_VALUE,
	GXML_GOM_ENUM_ENUM_TYPE
};
void gxml_gom_enum_initialize_enum (GXmlGomEnum* self, GType enum_type);
gint gxml_gom_enum_get_enum (GXmlGomEnum* self);
void gxml_gom_enum_set_enum (GXmlGomEnum* self, gint value);
GXmlGomEnum* gxml_gom_enum_new (void);
GXmlGomEnum* gxml_gom_enum_construct (GType object_type);
gchar* gxml_enumeration_get_string (GType enumeration, gint val, gboolean use_nick, gboolean camelcase, GError** error);
GType gxml_gom_enum_get_enum_type (GXmlGomEnum* self);
GEnumValue* gxml_enumeration_parse (GType enumeration, const gchar* val, GError** error);
void gxml_gom_enum_set_enum_type (GXmlGomEnum* self, GType value);
static void gxml_gom_enum_finalize (GObject* obj);
static void _vala_gxml_gom_enum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_enum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_date_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_DATE_DUMMY_PROPERTY,
	GXML_GOM_DATE_VALUE
};
void gxml_gom_date_get_date (GXmlGomDate* self, GDate* result);
void gxml_gom_date_set_date (GXmlGomDate* self, GDate* date);
GXmlGomDate* gxml_gom_date_new (void);
GXmlGomDate* gxml_gom_date_construct (GType object_type);
static void gxml_gom_date_finalize (GObject* obj);
static void _vala_gxml_gom_date_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_date_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gxml_gom_date_time_get_type (void) G_GNUC_CONST;
#define GXML_GOM_DATE_TIME_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTimePrivate))
enum  {
	GXML_GOM_DATE_TIME_DUMMY_PROPERTY,
	GXML_GOM_DATE_TIME_FORMAT,
	GXML_GOM_DATE_TIME_VALUE
};
GDateTime* gxml_gom_date_time_get_datetime (GXmlGomDateTime* self);
void gxml_gom_date_time_set_datetime (GXmlGomDateTime* self, GDateTime* dt);
GXmlGomDateTime* gxml_gom_date_time_new (void);
GXmlGomDateTime* gxml_gom_date_time_construct (GType object_type);
const gchar* gxml_gom_date_time_get_format (GXmlGomDateTime* self);
void gxml_gom_date_time_set_format (GXmlGomDateTime* self, const gchar* value);
static void gxml_gom_date_time_finalize (GObject* obj);
static void _vala_gxml_gom_date_time_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gxml_gom_date_time_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


/**
   * Takes a string and check if it is a valid value for property
   */
gboolean gxml_gom_property_validate_value (GXmlGomProperty* self, const gchar* val) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GOM_PROPERTY_GET_INTERFACE (self)->validate_value (self, val);
}


gchar* gxml_gom_property_get_value (GXmlGomProperty* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_PROPERTY_GET_INTERFACE (self)->get_value (self);
}


void gxml_gom_property_set_value (GXmlGomProperty* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_GOM_PROPERTY_GET_INTERFACE (self)->set_value (self, value);
}


static void gxml_gom_property_base_init (GXmlGomPropertyIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		/**
		   * Attribute's value in the parent {@link DomElement} using a string.
		   *
		   * Implementation should take care to validate value before to set or
		   * parse from XML document.
		   */
		g_object_interface_install_property (iface, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	}
}


/**
 * An interface for {@link GomObject}'s properties translated to
 * {@link DomElement} attributes. If object is instantiated it is
 * written, if not is just ingnored.
 */
GType gxml_gom_property_get_type (void) {
	static volatile gsize gxml_gom_property_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomPropertyIface), (GBaseInitFunc) gxml_gom_property_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_gom_property_type_id;
		gxml_gom_property_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlGomProperty", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_gom_property_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&gxml_gom_property_type_id__volatile, gxml_gom_property_type_id);
	}
	return gxml_gom_property_type_id__volatile;
}


/**
   * Takes a string and check if it can be valid for this property.
   */
static gboolean gxml_gom_base_property_real_validate_value (GXmlGomBaseProperty* self, const gchar* val) {
	gboolean result = FALSE;
	g_return_val_if_fail (val != NULL, FALSE);
	result = TRUE;
	return result;
}


gboolean gxml_gom_base_property_validate_value (GXmlGomBaseProperty* self, const gchar* val) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GOM_BASE_PROPERTY_GET_CLASS (self)->validate_value (self, val);
}


GXmlGomBaseProperty* gxml_gom_base_property_construct (GType object_type) {
	GXmlGomBaseProperty * self = NULL;
	self = (GXmlGomBaseProperty*) g_object_new (object_type, NULL);
	return self;
}


gchar* gxml_gom_base_property_get_value (GXmlGomBaseProperty* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_BASE_PROPERTY_GET_CLASS (self)->get_value (self);
}


void gxml_gom_base_property_set_value (GXmlGomBaseProperty* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_GOM_BASE_PROPERTY_GET_CLASS (self)->set_value (self, value);
}


static void gxml_gom_base_property_class_init (GXmlGomBasePropertyClass * klass) {
	gxml_gom_base_property_parent_class = g_type_class_peek_parent (klass);
	((GXmlGomBasePropertyClass *) klass)->validate_value = (gboolean (*)(GXmlGomBaseProperty*, const gchar*)) gxml_gom_base_property_real_validate_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_base_property_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_base_property_set_property;
	/**
	   * {@inheritDoc}
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_BASE_PROPERTY_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_base_property_gxml_gom_property_interface_init (GXmlGomPropertyIface * iface) {
	gxml_gom_base_property_gxml_gom_property_parent_iface = g_type_interface_peek_parent (iface);
	iface->validate_value = (gboolean (*)(GXmlGomProperty*, const gchar*)) gxml_gom_base_property_validate_value;
	iface->get_value = (gchar* (*) (GXmlGomProperty *)) gxml_gom_base_property_get_value;
	iface->set_value = (void (*) (GXmlGomProperty *, const gchar*)) gxml_gom_base_property_set_value;
}


static void gxml_gom_base_property_instance_init (GXmlGomBaseProperty * self) {
}


/**
 * Base class for properties implementing {@link GomProperty} interface.
 */
GType gxml_gom_base_property_get_type (void) {
	static volatile gsize gxml_gom_base_property_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_base_property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomBasePropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_base_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomBaseProperty), 0, (GInstanceInitFunc) gxml_gom_base_property_instance_init, NULL };
		static const GInterfaceInfo gxml_gom_property_info = { (GInterfaceInitFunc) gxml_gom_base_property_gxml_gom_property_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_base_property_type_id;
		gxml_gom_base_property_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGomBaseProperty", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (gxml_gom_base_property_type_id, GXML_TYPE_GOM_PROPERTY, &gxml_gom_property_info);
		g_once_init_leave (&gxml_gom_base_property_type_id__volatile, gxml_gom_base_property_type_id);
	}
	return gxml_gom_base_property_type_id__volatile;
}


static void _vala_gxml_gom_base_property_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomBaseProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_BASE_PROPERTY, GXmlGomBaseProperty);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_base_property_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomBaseProperty * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_BASE_PROPERTY, GXmlGomBaseProperty);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


GXmlGomString* gxml_gom_string_construct (GType object_type) {
	GXmlGomString * self = NULL;
	self = (GXmlGomString*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomString* gxml_gom_string_new (void) {
	return gxml_gom_string_construct (GXML_TYPE_GOM_STRING);
}


static gchar* gxml_gom_string_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomString* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomString*) base;
	_tmp0_ = self->_value;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static void gxml_gom_string_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomString* self;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	self = (GXmlGomString*) base;
	_tmp0_ = value;
	_tmp1_ = gxml_gom_base_property_validate_value ((GXmlGomBaseProperty*) self, _tmp0_);
	if (_tmp1_) {
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		_tmp2_ = value;
		_tmp3_ = g_strdup (_tmp2_);
		_g_free0 (self->_value);
		self->_value = _tmp3_;
	}
	g_object_notify ((GObject *) self, "value");
}


static void gxml_gom_string_class_init (GXmlGomStringClass * klass) {
	gxml_gom_string_parent_class = g_type_class_peek_parent (klass);
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_string_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_string_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_string_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_string_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_string_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_STRING_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_string_instance_init (GXmlGomString * self) {
	gchar* _tmp0_ = NULL;
	_tmp0_ = g_strdup ("");
	self->_value = _tmp0_;
}


static void gxml_gom_string_finalize (GObject* obj) {
	GXmlGomString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_STRING, GXmlGomString);
	_g_free0 (self->_value);
	G_OBJECT_CLASS (gxml_gom_string_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using validated string using Regular Expressions.
 */
GType gxml_gom_string_get_type (void) {
	static volatile gsize gxml_gom_string_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_string_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomStringClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_string_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomString), 0, (GInstanceInitFunc) gxml_gom_string_instance_init, NULL };
		GType gxml_gom_string_type_id;
		gxml_gom_string_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomString", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_string_type_id__volatile, gxml_gom_string_type_id);
	}
	return gxml_gom_string_type_id__volatile;
}


static void _vala_gxml_gom_string_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_STRING, GXmlGomString);
	switch (property_id) {
		case GXML_GOM_STRING_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_string_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_STRING, GXmlGomString);
	switch (property_id) {
		case GXML_GOM_STRING_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


gchar** gxml_gom_array_string_get_values (GXmlGomArrayString* self, int* result_length1) {
	gchar** result = NULL;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_values;
	_tmp0__length1 = self->_values_length1;
	_tmp1_ = _tmp0_;
	_tmp1__length1 = _tmp0__length1;
	if (result_length1) {
		*result_length1 = _tmp1__length1;
	}
	result = _tmp1_;
	return result;
}


/**
   * Convenient method to initialize array of values from an array of strings.
   * Values are taken and should not be freed after call initialization.
   */
static gchar** _vala_array_dup9 (gchar** self, int length) {
	gchar** result;
	int i;
	result = g_new0 (gchar*, length + 1);
	for (i = 0; i < length; i++) {
		gchar* _tmp0_ = NULL;
		_tmp0_ = g_strdup (self[i]);
		result[i] = _tmp0_;
	}
	return result;
}


void gxml_gom_array_string_initialize_strings (GXmlGomArrayString* self, gchar** strs, int strs_length1) {
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = strs;
	_tmp0__length1 = strs_length1;
	if (_tmp0__length1 == 0) {
		strs = (_vala_array_free (strs, strs_length1, (GDestroyNotify) g_free), NULL);
		return;
	}
	_tmp1_ = strs;
	_tmp1__length1 = strs_length1;
	_tmp2_ = (_tmp1_ != NULL) ? _vala_array_dup9 (_tmp1_, _tmp1__length1) : ((gpointer) _tmp1_);
	_tmp2__length1 = _tmp1__length1;
	self->_values = (_vala_array_free (self->_values, self->_values_length1, (GDestroyNotify) g_free), NULL);
	self->_values = _tmp2_;
	self->_values_length1 = _tmp2__length1;
	strs = (_vala_array_free (strs, strs_length1, (GDestroyNotify) g_free), NULL);
}


/**
   * Returns true if current value in attribute is included
   * in the array of values.
   */
gboolean gxml_gom_array_string_is_valid_value (GXmlGomArrayString* self) {
	gboolean result = FALSE;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->_values;
	_tmp0__length1 = self->_values_length1;
	if (_tmp0_ == NULL) {
		result = TRUE;
		return result;
	}
	_tmp1_ = self->_values;
	_tmp1__length1 = self->_values_length1;
	{
		gchar** s_collection = NULL;
		gint s_collection_length1 = 0;
		gint _s_collection_size_ = 0;
		gint s_it = 0;
		s_collection = _tmp1_;
		s_collection_length1 = _tmp1__length1;
		for (s_it = 0; s_it < _tmp1__length1; s_it = s_it + 1) {
			gchar* _tmp2_ = NULL;
			gchar* s = NULL;
			_tmp2_ = g_strdup (s_collection[s_it]);
			s = _tmp2_;
			{
				const gchar* _tmp3_ = NULL;
				gchar* _tmp4_ = NULL;
				gchar* _tmp5_ = NULL;
				gchar* _tmp6_ = NULL;
				gboolean _tmp7_ = FALSE;
				_tmp3_ = s;
				_tmp4_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self);
				_tmp5_ = _tmp4_;
				_tmp6_ = _tmp5_;
				_tmp7_ = g_strcmp0 (_tmp3_, _tmp6_) == 0;
				_g_free0 (_tmp6_);
				if (_tmp7_) {
					result = TRUE;
					_g_free0 (s);
					return result;
				}
				_g_free0 (s);
			}
		}
	}
	result = FALSE;
	return result;
}


/**
   * Select one string from array at index:
   */
void gxml_gom_array_string_select (GXmlGomArrayString* self, gint index) {
	gboolean _tmp0_ = FALSE;
	gint _tmp1_ = 0;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	gint _tmp5_ = 0;
	const gchar* _tmp6_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp1_ = index;
	if (_tmp1_ < 0) {
		_tmp0_ = TRUE;
	} else {
		gint _tmp2_ = 0;
		gchar** _tmp3_ = NULL;
		gint _tmp3__length1 = 0;
		_tmp2_ = index;
		_tmp3_ = self->_values;
		_tmp3__length1 = self->_values_length1;
		_tmp0_ = _tmp2_ > _tmp3__length1;
	}
	if (_tmp0_) {
		return;
	}
	_tmp4_ = self->_values;
	_tmp4__length1 = self->_values_length1;
	_tmp5_ = index;
	_tmp6_ = _tmp4_[_tmp5_];
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) self, _tmp6_);
}


/**
   * Check if string is in array
   */
gboolean gxml_gom_array_string_search (GXmlGomArrayString* self, const gchar* str) {
	gboolean result = FALSE;
	gchar** _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = self->_values;
	_tmp0__length1 = self->_values_length1;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp1_ = FALSE;
			_tmp1_ = TRUE;
			while (TRUE) {
				gint _tmp3_ = 0;
				gchar** _tmp4_ = NULL;
				gint _tmp4__length1 = 0;
				gchar** _tmp5_ = NULL;
				gint _tmp5__length1 = 0;
				gint _tmp6_ = 0;
				const gchar* _tmp7_ = NULL;
				const gchar* _tmp8_ = NULL;
				if (!_tmp1_) {
					gint _tmp2_ = 0;
					_tmp2_ = i;
					i = _tmp2_ + 1;
				}
				_tmp1_ = FALSE;
				_tmp3_ = i;
				_tmp4_ = self->_values;
				_tmp4__length1 = self->_values_length1;
				if (!(_tmp3_ < _tmp4__length1)) {
					break;
				}
				_tmp5_ = self->_values;
				_tmp5__length1 = self->_values_length1;
				_tmp6_ = i;
				_tmp7_ = _tmp5_[_tmp6_];
				_tmp8_ = str;
				if (g_strcmp0 (_tmp7_, _tmp8_) == 0) {
					result = TRUE;
					return result;
				}
			}
		}
	}
	result = FALSE;
	return result;
}


GXmlGomArrayString* gxml_gom_array_string_construct (GType object_type) {
	GXmlGomArrayString * self = NULL;
	self = (GXmlGomArrayString*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomArrayString* gxml_gom_array_string_new (void) {
	return gxml_gom_array_string_construct (GXML_TYPE_GOM_ARRAY_STRING);
}


static gchar* gxml_gom_array_string_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomArrayString* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomArrayString*) base;
	_tmp0_ = self->_value;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static void gxml_gom_array_string_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomArrayString* self;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	self = (GXmlGomArrayString*) base;
	_tmp0_ = value;
	_tmp1_ = gxml_gom_base_property_validate_value ((GXmlGomBaseProperty*) self, _tmp0_);
	if (_tmp1_) {
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		_tmp2_ = value;
		_tmp3_ = g_strdup (_tmp2_);
		_g_free0 (self->_value);
		self->_value = _tmp3_;
	}
	g_object_notify ((GObject *) self, "value");
}


static void gxml_gom_array_string_class_init (GXmlGomArrayStringClass * klass) {
	gxml_gom_array_string_parent_class = g_type_class_peek_parent (klass);
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_array_string_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_array_string_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_array_string_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_array_string_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_array_string_finalize;
	/**
	   * {inheritDoc}
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ARRAY_STRING_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_array_string_instance_init (GXmlGomArrayString * self) {
	gchar* _tmp0_ = NULL;
	_tmp0_ = g_strdup ("");
	self->_value = _tmp0_;
	self->_values = NULL;
	self->_values_length1 = 0;
}


static void gxml_gom_array_string_finalize (GObject* obj) {
	GXmlGomArrayString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ARRAY_STRING, GXmlGomArrayString);
	_g_free0 (self->_value);
	self->_values = (_vala_array_free (self->_values, self->_values_length1, (GDestroyNotify) g_free), NULL);
	G_OBJECT_CLASS (gxml_gom_array_string_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle a {@link GomElement}'s attribute
 * using a list of pre-defined and unmutable values.
 */
GType gxml_gom_array_string_get_type (void) {
	static volatile gsize gxml_gom_array_string_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_array_string_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomArrayStringClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_array_string_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomArrayString), 0, (GInstanceInitFunc) gxml_gom_array_string_instance_init, NULL };
		GType gxml_gom_array_string_type_id;
		gxml_gom_array_string_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomArrayString", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_array_string_type_id__volatile, gxml_gom_array_string_type_id);
	}
	return gxml_gom_array_string_type_id__volatile;
}


static void _vala_gxml_gom_array_string_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomArrayString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ARRAY_STRING, GXmlGomArrayString);
	switch (property_id) {
		case GXML_GOM_ARRAY_STRING_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_array_string_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomArrayString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ARRAY_STRING, GXmlGomArrayString);
	switch (property_id) {
		case GXML_GOM_ARRAY_STRING_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Load list of strings from a {@link GLib.File}, parsing using an
   * {@link GomXsdSchema} object and searching for {@link IXsdSimpleType}
   * definition with name {@link simple_type}.
   */
static void _vala_array_add10 (gchar*** array, int* length, int* size, gchar* value) {
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}


static gchar** _vala_array_dup10 (gchar** self, int length) {
	gchar** result;
	int i;
	result = g_new0 (gchar*, length + 1);
	for (i = 0; i < length; i++) {
		gchar* _tmp0_ = NULL;
		_tmp0_ = g_strdup (self[i]);
		result[i] = _tmp0_;
	}
	return result;
}


void gxml_gom_xsd_array_string_load (GXmlGomXsdArrayString* self, GError** error) {
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
	GXmlGomXsdSchema* xsd = NULL;
	GXmlGomXsdSchema* _tmp4_ = NULL;
	GXmlGomXsdSchema* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
	GXmlGomXsdSchema* _tmp7_ = NULL;
	GXmlGomXsdListSimpleTypes* _tmp8_ = NULL;
	GXmlGomXsdListSimpleTypes* _tmp9_ = NULL;
	GXmlGomXsdSchema* _tmp10_ = NULL;
	GXmlGomXsdListSimpleTypes* _tmp11_ = NULL;
	GXmlGomXsdListSimpleTypes* _tmp12_ = NULL;
	gint _tmp13_ = 0;
	gint _tmp14_ = 0;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->_source;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->_source;
	_tmp2_ = g_file_query_exists (_tmp1_, NULL);
	if (!_tmp2_) {
		return;
	}
	_tmp3_ = self->_simple_type;
	if (_tmp3_ == NULL) {
		return;
	}
	_tmp4_ = gxml_gom_xsd_schema_new ();
	xsd = _tmp4_;
	_tmp5_ = xsd;
	_tmp6_ = self->_source;
	gxml_gom_element_read_from_file ((GXmlGomElement*) _tmp5_, _tmp6_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (xsd);
		return;
	}
	_tmp7_ = xsd;
	_tmp8_ = gxml_gom_xsd_schema_get_simple_type_definitions (_tmp7_);
	_tmp9_ = _tmp8_;
	if (_tmp9_ == NULL) {
		_g_object_unref0 (xsd);
		return;
	}
	_tmp10_ = xsd;
	_tmp11_ = gxml_gom_xsd_schema_get_simple_type_definitions (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = gxml_gom_xsd_list_get_length ((GXmlGomXsdList*) _tmp12_);
	_tmp14_ = _tmp13_;
	if (_tmp14_ == 0) {
		_g_object_unref0 (xsd);
		return;
	}
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp15_ = FALSE;
			_tmp15_ = TRUE;
			while (TRUE) {
				gint _tmp17_ = 0;
				GXmlGomXsdSchema* _tmp18_ = NULL;
				GXmlGomXsdListSimpleTypes* _tmp19_ = NULL;
				GXmlGomXsdListSimpleTypes* _tmp20_ = NULL;
				gint _tmp21_ = 0;
				gint _tmp22_ = 0;
				GXmlDomElement* _tmp23_ = NULL;
				GXmlGomXsdSchema* _tmp24_ = NULL;
				GXmlGomXsdListSimpleTypes* _tmp25_ = NULL;
				GXmlGomXsdListSimpleTypes* _tmp26_ = NULL;
				gint _tmp27_ = 0;
				GXmlDomElement* _tmp28_ = NULL;
				GXmlGomXsdSimpleType* st = NULL;
				GXmlDomElement* _tmp29_ = NULL;
				GXmlGomXsdSimpleType* _tmp30_ = NULL;
				GXmlGomXsdSimpleType* _tmp31_ = NULL;
				GXmlGomXsdSimpleType* _tmp32_ = NULL;
				const gchar* _tmp33_ = NULL;
				const gchar* _tmp34_ = NULL;
				const gchar* _tmp35_ = NULL;
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				GXmlGomXsdSimpleType* _tmp38_ = NULL;
				const gchar* _tmp39_ = NULL;
				const gchar* _tmp40_ = NULL;
				gchar* _tmp41_ = NULL;
				gchar* _tmp42_ = NULL;
				gboolean _tmp43_ = FALSE;
				if (!_tmp15_) {
					gint _tmp16_ = 0;
					_tmp16_ = i;
					i = _tmp16_ + 1;
				}
				_tmp15_ = FALSE;
				_tmp17_ = i;
				_tmp18_ = xsd;
				_tmp19_ = gxml_gom_xsd_schema_get_simple_type_definitions (_tmp18_);
				_tmp20_ = _tmp19_;
				_tmp21_ = gxml_gom_xsd_list_get_length ((GXmlGomXsdList*) _tmp20_);
				_tmp22_ = _tmp21_;
				if (!(_tmp17_ < _tmp22_)) {
					break;
				}
				_tmp24_ = xsd;
				_tmp25_ = gxml_gom_xsd_schema_get_simple_type_definitions (_tmp24_);
				_tmp26_ = _tmp25_;
				_tmp27_ = i;
				_tmp28_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp26_, _tmp27_, &_inner_error_);
				_tmp23_ = _tmp28_;
				if (G_UNLIKELY (_inner_error_ != NULL)) {
					g_propagate_error (error, _inner_error_);
					_g_object_unref0 (xsd);
					return;
				}
				_tmp29_ = _tmp23_;
				_tmp23_ = NULL;
				_tmp30_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_GOM_XSD_SIMPLE_TYPE) ? ((GXmlGomXsdSimpleType*) _tmp29_) : NULL;
				if (_tmp30_ == NULL) {
					_g_object_unref0 (_tmp29_);
				}
				st = _tmp30_;
				_tmp31_ = st;
				if (_tmp31_ == NULL) {
					_g_object_unref0 (st);
					_g_object_unref0 (_tmp23_);
					continue;
				}
				_tmp32_ = st;
				_tmp33_ = gxml_gom_xsd_simple_type_get_name (_tmp32_);
				_tmp34_ = _tmp33_;
				if (_tmp34_ == NULL) {
					_g_object_unref0 (st);
					_g_object_unref0 (_tmp23_);
					continue;
				}
				_tmp35_ = self->_simple_type;
				_tmp36_ = g_utf8_strdown (_tmp35_, (gssize) -1);
				_tmp37_ = _tmp36_;
				_tmp38_ = st;
				_tmp39_ = gxml_gom_xsd_simple_type_get_name (_tmp38_);
				_tmp40_ = _tmp39_;
				_tmp41_ = g_utf8_strdown (_tmp40_, (gssize) -1);
				_tmp42_ = _tmp41_;
				_tmp43_ = g_strcmp0 (_tmp37_, _tmp42_) == 0;
				_g_free0 (_tmp42_);
				_g_free0 (_tmp37_);
				if (_tmp43_) {
					GXmlGomXsdSimpleType* _tmp44_ = NULL;
					GXmlGomXsdTypeRestriction* _tmp45_ = NULL;
					GXmlGomXsdTypeRestriction* _tmp46_ = NULL;
					GXmlGomXsdSimpleType* _tmp47_ = NULL;
					GXmlGomXsdTypeRestriction* _tmp48_ = NULL;
					GXmlGomXsdTypeRestriction* _tmp49_ = NULL;
					GXmlGomXsdListTypeRestrictionEnumerations* _tmp50_ = NULL;
					GXmlGomXsdListTypeRestrictionEnumerations* _tmp51_ = NULL;
					GXmlGomXsdSimpleType* _tmp52_ = NULL;
					GXmlGomXsdTypeRestriction* _tmp53_ = NULL;
					GXmlGomXsdTypeRestriction* _tmp54_ = NULL;
					GXmlGomXsdListTypeRestrictionEnumerations* _tmp55_ = NULL;
					GXmlGomXsdListTypeRestrictionEnumerations* _tmp56_ = NULL;
					gint _tmp57_ = 0;
					gint _tmp58_ = 0;
					gchar** vals = NULL;
					gchar** _tmp59_ = NULL;
					gint vals_length1 = 0;
					gint _vals_size_ = 0;
					gchar** _tmp89_ = NULL;
					gint _tmp89__length1 = 0;
					gchar** _tmp90_ = NULL;
					gint _tmp90__length1 = 0;
					_tmp44_ = st;
					_tmp45_ = gxml_gom_xsd_simple_type_get_restriction (_tmp44_);
					_tmp46_ = _tmp45_;
					if (_tmp46_ == NULL) {
						_g_object_unref0 (st);
						_g_object_unref0 (_tmp23_);
						continue;
					}
					_tmp47_ = st;
					_tmp48_ = gxml_gom_xsd_simple_type_get_restriction (_tmp47_);
					_tmp49_ = _tmp48_;
					_tmp50_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp49_);
					_tmp51_ = _tmp50_;
					if (_tmp51_ == NULL) {
						_g_object_unref0 (st);
						_g_object_unref0 (_tmp23_);
						continue;
					}
					_tmp52_ = st;
					_tmp53_ = gxml_gom_xsd_simple_type_get_restriction (_tmp52_);
					_tmp54_ = _tmp53_;
					_tmp55_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp54_);
					_tmp56_ = _tmp55_;
					_tmp57_ = gxml_gom_xsd_list_get_length ((GXmlGomXsdList*) _tmp56_);
					_tmp58_ = _tmp57_;
					if (_tmp58_ == 0) {
						_g_object_unref0 (st);
						_g_object_unref0 (_tmp23_);
						continue;
					}
					_tmp59_ = g_new0 (gchar*, 0 + 1);
					vals = _tmp59_;
					vals_length1 = 0;
					_vals_size_ = vals_length1;
					{
						gint j = 0;
						j = 0;
						{
							gboolean _tmp60_ = FALSE;
							_tmp60_ = TRUE;
							while (TRUE) {
								gint _tmp62_ = 0;
								GXmlGomXsdSimpleType* _tmp63_ = NULL;
								GXmlGomXsdTypeRestriction* _tmp64_ = NULL;
								GXmlGomXsdTypeRestriction* _tmp65_ = NULL;
								GXmlGomXsdListTypeRestrictionEnumerations* _tmp66_ = NULL;
								GXmlGomXsdListTypeRestrictionEnumerations* _tmp67_ = NULL;
								gint _tmp68_ = 0;
								gint _tmp69_ = 0;
								GXmlDomElement* _tmp70_ = NULL;
								GXmlGomXsdSimpleType* _tmp71_ = NULL;
								GXmlGomXsdTypeRestriction* _tmp72_ = NULL;
								GXmlGomXsdTypeRestriction* _tmp73_ = NULL;
								GXmlGomXsdListTypeRestrictionEnumerations* _tmp74_ = NULL;
								GXmlGomXsdListTypeRestrictionEnumerations* _tmp75_ = NULL;
								gint _tmp76_ = 0;
								GXmlDomElement* _tmp77_ = NULL;
								GXmlGomXsdTypeRestrictionEnumeration* en = NULL;
								GXmlDomElement* _tmp78_ = NULL;
								GXmlGomXsdTypeRestrictionEnumeration* _tmp79_ = NULL;
								GXmlGomXsdTypeRestrictionEnumeration* _tmp80_ = NULL;
								GXmlGomXsdTypeRestrictionEnumeration* _tmp81_ = NULL;
								const gchar* _tmp82_ = NULL;
								const gchar* _tmp83_ = NULL;
								gchar** _tmp84_ = NULL;
								gint _tmp84__length1 = 0;
								GXmlGomXsdTypeRestrictionEnumeration* _tmp85_ = NULL;
								const gchar* _tmp86_ = NULL;
								const gchar* _tmp87_ = NULL;
								gchar* _tmp88_ = NULL;
								if (!_tmp60_) {
									gint _tmp61_ = 0;
									_tmp61_ = j;
									j = _tmp61_ + 1;
								}
								_tmp60_ = FALSE;
								_tmp62_ = j;
								_tmp63_ = st;
								_tmp64_ = gxml_gom_xsd_simple_type_get_restriction (_tmp63_);
								_tmp65_ = _tmp64_;
								_tmp66_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp65_);
								_tmp67_ = _tmp66_;
								_tmp68_ = gxml_gom_xsd_list_get_length ((GXmlGomXsdList*) _tmp67_);
								_tmp69_ = _tmp68_;
								if (!(_tmp62_ < _tmp69_)) {
									break;
								}
								_tmp71_ = st;
								_tmp72_ = gxml_gom_xsd_simple_type_get_restriction (_tmp71_);
								_tmp73_ = _tmp72_;
								_tmp74_ = gxml_gom_xsd_type_restriction_get_enumerations (_tmp73_);
								_tmp75_ = _tmp74_;
								_tmp76_ = j;
								_tmp77_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp75_, _tmp76_, &_inner_error_);
								_tmp70_ = _tmp77_;
								if (G_UNLIKELY (_inner_error_ != NULL)) {
									g_propagate_error (error, _inner_error_);
									vals = (_vala_array_free (vals, vals_length1, (GDestroyNotify) g_free), NULL);
									_g_object_unref0 (st);
									_g_object_unref0 (_tmp23_);
									_g_object_unref0 (xsd);
									return;
								}
								_tmp78_ = _tmp70_;
								_tmp70_ = NULL;
								_tmp79_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp78_, GXML_TYPE_GOM_XSD_TYPE_RESTRICTION_ENUMERATION) ? ((GXmlGomXsdTypeRestrictionEnumeration*) _tmp78_) : NULL;
								if (_tmp79_ == NULL) {
									_g_object_unref0 (_tmp78_);
								}
								en = _tmp79_;
								_tmp80_ = en;
								if (_tmp80_ == NULL) {
									_g_object_unref0 (en);
									_g_object_unref0 (_tmp70_);
									continue;
								}
								_tmp81_ = en;
								_tmp82_ = gxml_gom_xsd_type_restriction_enumeration_get_value (_tmp81_);
								_tmp83_ = _tmp82_;
								if (_tmp83_ == NULL) {
									_g_object_unref0 (en);
									_g_object_unref0 (_tmp70_);
									continue;
								}
								_tmp84_ = vals;
								_tmp84__length1 = vals_length1;
								_tmp85_ = en;
								_tmp86_ = gxml_gom_xsd_type_restriction_enumeration_get_value (_tmp85_);
								_tmp87_ = _tmp86_;
								_tmp88_ = g_strdup (_tmp87_);
								_vala_array_add10 (&vals, &vals_length1, &_vals_size_, _tmp88_);
								_g_object_unref0 (en);
								_g_object_unref0 (_tmp70_);
							}
						}
					}
					_tmp89_ = vals;
					_tmp89__length1 = vals_length1;
					_tmp90_ = (_tmp89_ != NULL) ? _vala_array_dup10 (_tmp89_, _tmp89__length1) : ((gpointer) _tmp89_);
					_tmp90__length1 = _tmp89__length1;
					gxml_gom_array_string_initialize_strings ((GXmlGomArrayString*) self, _tmp90_, _tmp90__length1);
					vals = (_vala_array_free (vals, vals_length1, (GDestroyNotify) g_free), NULL);
				}
				_g_object_unref0 (st);
				_g_object_unref0 (_tmp23_);
			}
		}
	}
	_g_object_unref0 (xsd);
}


GXmlGomXsdArrayString* gxml_gom_xsd_array_string_construct (GType object_type) {
	GXmlGomXsdArrayString * self = NULL;
	self = (GXmlGomXsdArrayString*) gxml_gom_array_string_construct (object_type);
	return self;
}


GXmlGomXsdArrayString* gxml_gom_xsd_array_string_new (void) {
	return gxml_gom_xsd_array_string_construct (GXML_TYPE_GOM_XSD_ARRAY_STRING);
}


const gchar* gxml_gom_xsd_array_string_get_simple_type (GXmlGomXsdArrayString* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_simple_type;
	result = _tmp0_;
	return result;
}


void gxml_gom_xsd_array_string_set_simple_type (GXmlGomXsdArrayString* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->_simple_type);
	self->_simple_type = _tmp1_;
	g_object_notify ((GObject *) self, "simple-type");
}


GFile* gxml_gom_xsd_array_string_get_source (GXmlGomXsdArrayString* self) {
	GFile* result;
	GFile* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_source;
	result = _tmp0_;
	return result;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


void gxml_gom_xsd_array_string_set_source (GXmlGomXsdArrayString* self, GFile* value) {
	GFile* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_file_query_exists (_tmp0_, NULL);
	if (!_tmp1_) {
		return;
	}
	_tmp2_ = value;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	_g_object_unref0 (self->_source);
	self->_source = _tmp3_;
	g_object_notify ((GObject *) self, "source");
}


static void gxml_gom_xsd_array_string_class_init (GXmlGomXsdArrayStringClass * klass) {
	gxml_gom_xsd_array_string_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_xsd_array_string_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_xsd_array_string_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_xsd_array_string_finalize;
	/**
	   * Name of {@link IXsdSimpleType} to use as source.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_XSD_ARRAY_STRING_SIMPLE_TYPE, g_param_spec_string ("simple-type", "simple-type", "simple-type", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * A {@link GLib.File} source to read from, simple type definitions in
	   * an XSD file type.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_XSD_ARRAY_STRING_SOURCE, g_param_spec_object ("source", "source", "source", g_file_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_xsd_array_string_instance_init (GXmlGomXsdArrayString * self) {
	self->_source = NULL;
	self->_simple_type = NULL;
}


static void gxml_gom_xsd_array_string_finalize (GObject* obj) {
	GXmlGomXsdArrayString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_XSD_ARRAY_STRING, GXmlGomXsdArrayString);
	_g_object_unref0 (self->_source);
	_g_free0 (self->_simple_type);
	G_OBJECT_CLASS (gxml_gom_xsd_array_string_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle a {@link GomElement}'s attribute
 * using a list of pre-defined and unmutable values, taken from
 * an {@link IXsdSimpleType} definition
 */
GType gxml_gom_xsd_array_string_get_type (void) {
	static volatile gsize gxml_gom_xsd_array_string_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_xsd_array_string_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomXsdArrayStringClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_xsd_array_string_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomXsdArrayString), 0, (GInstanceInitFunc) gxml_gom_xsd_array_string_instance_init, NULL };
		GType gxml_gom_xsd_array_string_type_id;
		gxml_gom_xsd_array_string_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_STRING, "GXmlGomXsdArrayString", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_xsd_array_string_type_id__volatile, gxml_gom_xsd_array_string_type_id);
	}
	return gxml_gom_xsd_array_string_type_id__volatile;
}


static void _vala_gxml_gom_xsd_array_string_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomXsdArrayString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_XSD_ARRAY_STRING, GXmlGomXsdArrayString);
	switch (property_id) {
		case GXML_GOM_XSD_ARRAY_STRING_SIMPLE_TYPE:
		g_value_set_string (value, gxml_gom_xsd_array_string_get_simple_type (self));
		break;
		case GXML_GOM_XSD_ARRAY_STRING_SOURCE:
		g_value_set_object (value, gxml_gom_xsd_array_string_get_source (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_xsd_array_string_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomXsdArrayString * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_XSD_ARRAY_STRING, GXmlGomXsdArrayString);
	switch (property_id) {
		case GXML_GOM_XSD_ARRAY_STRING_SIMPLE_TYPE:
		gxml_gom_xsd_array_string_set_simple_type (self, g_value_get_string (value));
		break;
		case GXML_GOM_XSD_ARRAY_STRING_SOURCE:
		gxml_gom_xsd_array_string_set_source (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Retrive current value.
   */
gdouble gxml_gom_double_get_double (GXmlGomDouble* self) {
	gdouble result = 0.0;
	gdouble _tmp0_ = 0.0;
	g_return_val_if_fail (self != NULL, 0.0);
	_tmp0_ = self->_value;
	result = _tmp0_;
	return result;
}


/**
   * Sets current value.
   */
void gxml_gom_double_set_double (GXmlGomDouble* self, gdouble value) {
	gdouble _tmp0_ = 0.0;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->_value = _tmp0_;
}


GXmlGomDouble* gxml_gom_double_construct (GType object_type) {
	GXmlGomDouble * self = NULL;
	self = (GXmlGomDouble*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomDouble* gxml_gom_double_new (void) {
	return gxml_gom_double_construct (GXML_TYPE_GOM_DOUBLE);
}


static gchar* gxml_gom_double_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomDouble* self;
	gchar* s = NULL;
	guint _tmp0_ = 0U;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gdouble _tmp7_ = 0.0;
	gchar* _tmp8_ = NULL;
	self = (GXmlGomDouble*) base;
	_tmp0_ = self->priv->_decimals;
	_tmp1_ = g_strdup_printf ("%u", _tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strconcat ("%.", _tmp2_, NULL);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strconcat (_tmp4_, "f", NULL);
	_tmp6_ = _tmp5_;
	_g_free0 (_tmp4_);
	_g_free0 (_tmp2_);
	s = _tmp6_;
	_tmp7_ = self->_value;
	_tmp8_ = g_strdup_printf (s, _tmp7_);
	result = _tmp8_;
	_g_free0 (s);
	return result;
}


static gdouble double_parse (const gchar* str) {
	gdouble result = 0.0;
	const gchar* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	g_return_val_if_fail (str != NULL, 0.0);
	_tmp0_ = str;
	_tmp1_ = g_ascii_strtod (_tmp0_, NULL);
	result = _tmp1_;
	return result;
}


static void gxml_gom_double_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomDouble* self;
	const gchar* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	self = (GXmlGomDouble*) base;
	_tmp0_ = value;
	_tmp1_ = double_parse (_tmp0_);
	self->_value = _tmp1_;
	g_object_notify ((GObject *) self, "value");
}


guint gxml_gom_double_get_decimals (GXmlGomDouble* self) {
	guint result;
	guint _tmp0_ = 0U;
	g_return_val_if_fail (self != NULL, 0U);
	_tmp0_ = self->priv->_decimals;
	result = _tmp0_;
	return result;
}


void gxml_gom_double_set_decimals (GXmlGomDouble* self, guint value) {
	guint _tmp0_ = 0U;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->priv->_decimals = _tmp0_;
	g_object_notify ((GObject *) self, "decimals");
}


static void gxml_gom_double_class_init (GXmlGomDoubleClass * klass) {
	gxml_gom_double_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlGomDoublePrivate));
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_double_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_double_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_double_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_double_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_double_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOUBLE_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * Set number of decimals to write out as {@link GomElement}'s property.
	   * Default is 4.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOUBLE_DECIMALS, g_param_spec_uint ("decimals", "decimals", "decimals", 0, G_MAXUINT, (guint) 4, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_double_instance_init (GXmlGomDouble * self) {
	self->priv = GXML_GOM_DOUBLE_GET_PRIVATE (self);
	self->_value = 0.0;
	self->priv->_decimals = (guint) 4;
}


static void gxml_gom_double_finalize (GObject* obj) {
	GXmlGomDouble * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_DOUBLE, GXmlGomDouble);
	G_OBJECT_CLASS (gxml_gom_double_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using double pressition floats as sources of values.
 *
 * Property is represented as a string.
 */
GType gxml_gom_double_get_type (void) {
	static volatile gsize gxml_gom_double_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_double_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomDoubleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_double_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomDouble), 0, (GInstanceInitFunc) gxml_gom_double_instance_init, NULL };
		GType gxml_gom_double_type_id;
		gxml_gom_double_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomDouble", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_double_type_id__volatile, gxml_gom_double_type_id);
	}
	return gxml_gom_double_type_id__volatile;
}


static void _vala_gxml_gom_double_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomDouble * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DOUBLE, GXmlGomDouble);
	switch (property_id) {
		case GXML_GOM_DOUBLE_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		case GXML_GOM_DOUBLE_DECIMALS:
		g_value_set_uint (value, gxml_gom_double_get_decimals (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_double_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomDouble * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DOUBLE, GXmlGomDouble);
	switch (property_id) {
		case GXML_GOM_DOUBLE_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		case GXML_GOM_DOUBLE_DECIMALS:
		gxml_gom_double_set_decimals (self, g_value_get_uint (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Retrive current value.
   */
gfloat gxml_gom_float_get_float (GXmlGomFloat* self) {
	gfloat result = 0.0F;
	gdouble _tmp0_ = 0.0;
	g_return_val_if_fail (self != NULL, 0.0F);
	_tmp0_ = ((GXmlGomDouble*) self)->_value;
	result = (gfloat) _tmp0_;
	return result;
}


/**
   * Sets current value.
   */
void gxml_gom_float_set_float (GXmlGomFloat* self, gfloat value) {
	gfloat _tmp0_ = 0.0F;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	((GXmlGomDouble*) self)->_value = (gdouble) _tmp0_;
}


GXmlGomFloat* gxml_gom_float_construct (GType object_type) {
	GXmlGomFloat * self = NULL;
	self = (GXmlGomFloat*) gxml_gom_double_construct (object_type);
	return self;
}


GXmlGomFloat* gxml_gom_float_new (void) {
	return gxml_gom_float_construct (GXML_TYPE_GOM_FLOAT);
}


static void gxml_gom_float_class_init (GXmlGomFloatClass * klass) {
	gxml_gom_float_parent_class = g_type_class_peek_parent (klass);
}


static void gxml_gom_float_instance_init (GXmlGomFloat * self) {
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using floats as sources of values.
 *
 * Property is represented as a string.
 */
GType gxml_gom_float_get_type (void) {
	static volatile gsize gxml_gom_float_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_float_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomFloatClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_float_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomFloat), 0, (GInstanceInitFunc) gxml_gom_float_instance_init, NULL };
		GType gxml_gom_float_type_id;
		gxml_gom_float_type_id = g_type_register_static (GXML_TYPE_GOM_DOUBLE, "GXmlGomFloat", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_float_type_id__volatile, gxml_gom_float_type_id);
	}
	return gxml_gom_float_type_id__volatile;
}


/**
   * Retrive current value.
   */
gint gxml_gom_int_get_integer (GXmlGomInt* self) {
	gint result = 0;
	gint _tmp0_ = 0;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = self->_value;
	result = _tmp0_;
	return result;
}


/**
   * Sets current value.
   */
void gxml_gom_int_set_integer (GXmlGomInt* self, gint value) {
	gint _tmp0_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->_value = _tmp0_;
}


GXmlGomInt* gxml_gom_int_construct (GType object_type) {
	GXmlGomInt * self = NULL;
	self = (GXmlGomInt*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomInt* gxml_gom_int_new (void) {
	return gxml_gom_int_construct (GXML_TYPE_GOM_INT);
}


static gchar* gxml_gom_int_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomInt* self;
	gint _tmp0_ = 0;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomInt*) base;
	_tmp0_ = self->_value;
	_tmp1_ = g_strdup_printf ("%i", _tmp0_);
	result = _tmp1_;
	return result;
}


static void gxml_gom_int_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomInt* self;
	const gchar* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	self = (GXmlGomInt*) base;
	_tmp0_ = value;
	_tmp1_ = double_parse (_tmp0_);
	self->_value = (gint) _tmp1_;
	g_object_notify ((GObject *) self, "value");
}


static void gxml_gom_int_class_init (GXmlGomIntClass * klass) {
	gxml_gom_int_parent_class = g_type_class_peek_parent (klass);
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_int_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_int_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_int_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_int_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_int_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_INT_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_int_instance_init (GXmlGomInt * self) {
	self->_value = 0;
}


static void gxml_gom_int_finalize (GObject* obj) {
	GXmlGomInt * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_INT, GXmlGomInt);
	G_OBJECT_CLASS (gxml_gom_int_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using a integers as sources of values.
 *
 * Property is represented as a string.
 */
GType gxml_gom_int_get_type (void) {
	static volatile gsize gxml_gom_int_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_int_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomIntClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_int_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomInt), 0, (GInstanceInitFunc) gxml_gom_int_instance_init, NULL };
		GType gxml_gom_int_type_id;
		gxml_gom_int_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomInt", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_int_type_id__volatile, gxml_gom_int_type_id);
	}
	return gxml_gom_int_type_id__volatile;
}


static void _vala_gxml_gom_int_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomInt * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_INT, GXmlGomInt);
	switch (property_id) {
		case GXML_GOM_INT_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_int_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomInt * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_INT, GXmlGomInt);
	switch (property_id) {
		case GXML_GOM_INT_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Retrive current value.
   */
gboolean gxml_gom_boolean_get_boolean (GXmlGomBoolean* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->_value;
	result = _tmp0_;
	return result;
}


/**
   * Sets current value.
   */
void gxml_gom_boolean_set_boolean (GXmlGomBoolean* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->_value = _tmp0_;
}


GXmlGomBoolean* gxml_gom_boolean_construct (GType object_type) {
	GXmlGomBoolean * self = NULL;
	self = (GXmlGomBoolean*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomBoolean* gxml_gom_boolean_new (void) {
	return gxml_gom_boolean_construct (GXML_TYPE_GOM_BOOLEAN);
}


static gchar* bool_to_string (gboolean self) {
	gchar* result = NULL;
	if (self) {
		gchar* _tmp0_ = NULL;
		_tmp0_ = g_strdup ("true");
		result = _tmp0_;
		return result;
	} else {
		gchar* _tmp1_ = NULL;
		_tmp1_ = g_strdup ("false");
		result = _tmp1_;
		return result;
	}
}


static gchar* gxml_gom_boolean_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomBoolean* self;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomBoolean*) base;
	_tmp0_ = self->_value;
	_tmp1_ = bool_to_string (_tmp0_);
	result = _tmp1_;
	return result;
}


static gboolean bool_parse (const gchar* str) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = str;
	if (g_strcmp0 (_tmp0_, "true") == 0) {
		result = TRUE;
		return result;
	} else {
		result = FALSE;
		return result;
	}
}


static void gxml_gom_boolean_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomBoolean* self;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	self = (GXmlGomBoolean*) base;
	_tmp0_ = value;
	_tmp1_ = bool_parse (_tmp0_);
	self->_value = _tmp1_;
	g_object_notify ((GObject *) self, "value");
}


static void gxml_gom_boolean_class_init (GXmlGomBooleanClass * klass) {
	gxml_gom_boolean_parent_class = g_type_class_peek_parent (klass);
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_boolean_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_boolean_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_boolean_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_boolean_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_boolean_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_BOOLEAN_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_boolean_instance_init (GXmlGomBoolean * self) {
	self->_value = FALSE;
}


static void gxml_gom_boolean_finalize (GObject* obj) {
	GXmlGomBoolean * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_BOOLEAN, GXmlGomBoolean);
	G_OBJECT_CLASS (gxml_gom_boolean_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using a boolean ('true' and 'false') as sources of values.
 *
 * Property is represented as a string, using 'true' or 'false'.
 */
GType gxml_gom_boolean_get_type (void) {
	static volatile gsize gxml_gom_boolean_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_boolean_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomBooleanClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_boolean_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomBoolean), 0, (GInstanceInitFunc) gxml_gom_boolean_instance_init, NULL };
		GType gxml_gom_boolean_type_id;
		gxml_gom_boolean_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomBoolean", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_boolean_type_id__volatile, gxml_gom_boolean_type_id);
	}
	return gxml_gom_boolean_type_id__volatile;
}


static void _vala_gxml_gom_boolean_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomBoolean * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_BOOLEAN, GXmlGomBoolean);
	switch (property_id) {
		case GXML_GOM_BOOLEAN_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_boolean_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomBoolean * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_BOOLEAN, GXmlGomBoolean);
	switch (property_id) {
		case GXML_GOM_BOOLEAN_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Convenient method to initialize internal enum type.
   */
void gxml_gom_enum_initialize_enum (GXmlGomEnum* self, GType enum_type) {
	GType _tmp0_ = 0UL;
	g_return_if_fail (self != NULL);
	_tmp0_ = enum_type;
	self->_enum_type = _tmp0_;
}


/**
   * Retrive current value.
   */
gint gxml_gom_enum_get_enum (GXmlGomEnum* self) {
	gint result = 0;
	gint _tmp0_ = 0;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = self->_value;
	result = (gint) _tmp0_;
	return result;
}


/**
   * Sets current value.
   */
void gxml_gom_enum_set_enum (GXmlGomEnum* self, gint value) {
	gint _tmp0_ = 0;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->_value = _tmp0_;
}


GXmlGomEnum* gxml_gom_enum_construct (GType object_type) {
	GXmlGomEnum * self = NULL;
	self = (GXmlGomEnum*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomEnum* gxml_gom_enum_new (void) {
	return gxml_gom_enum_construct (GXML_TYPE_GOM_ENUM);
}


static gchar* gxml_gom_enum_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomEnum* self;
	gchar* s = NULL;
	gchar* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomEnum*) base;
	_tmp0_ = g_strdup ("");
	s = _tmp0_;
	{
		gchar* _tmp1_ = NULL;
		GType _tmp2_ = 0UL;
		GType _tmp3_ = 0UL;
		gint _tmp4_ = 0;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		_tmp2_ = gxml_gom_enum_get_enum_type (self);
		_tmp3_ = _tmp2_;
		_tmp4_ = self->_value;
		_tmp5_ = gxml_enumeration_get_string (_tmp3_, _tmp4_, TRUE, TRUE, &_inner_error_);
		_tmp1_ = _tmp5_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			goto __catch24_g_error;
		}
		_tmp6_ = _tmp1_;
		_tmp1_ = NULL;
		_g_free0 (s);
		s = _tmp6_;
		_g_free0 (_tmp1_);
	}
	goto __finally24;
	__catch24_g_error:
	{
		const gchar* _tmp7_ = NULL;
		g_clear_error (&_inner_error_);
		_inner_error_ = NULL;
		_tmp7_ = _ ("Error when transform enum to attribute's value");
		g_warning ("GomProperty.vala:333: %s", _tmp7_);
	}
	__finally24:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		_g_free0 (s);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return NULL;
	}
	result = s;
	return result;
}


static void gxml_gom_enum_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomEnum* self;
	GError * _inner_error_ = NULL;
	self = (GXmlGomEnum*) base;
	{
		GEnumValue* _tmp0_ = NULL;
		GType _tmp1_ = 0UL;
		GType _tmp2_ = 0UL;
		const gchar* _tmp3_ = NULL;
		GEnumValue* _tmp4_ = NULL;
		GEnumValue* _tmp5_ = NULL;
		GEnumValue* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		_tmp1_ = gxml_gom_enum_get_enum_type (self);
		_tmp2_ = _tmp1_;
		_tmp3_ = value;
		_tmp4_ = gxml_enumeration_parse (_tmp2_, _tmp3_, &_inner_error_);
		_tmp0_ = _tmp4_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			goto __catch25_g_error;
		}
		_tmp5_ = _tmp0_;
		_tmp0_ = NULL;
		_tmp6_ = _tmp5_;
		_tmp7_ = (*_tmp6_).value;
		self->_value = (gint) _tmp7_;
		_g_free0 (_tmp6_);
		_g_free0 (_tmp0_);
	}
	goto __finally25;
	__catch25_g_error:
	{
		const gchar* _tmp8_ = NULL;
		g_clear_error (&_inner_error_);
		_inner_error_ = NULL;
		_tmp8_ = _ ("Error when transform from attribute string value to enum");
		g_warning ("GomProperty.vala:341: %s", _tmp8_);
	}
	__finally25:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
	g_object_notify ((GObject *) self, "value");
}


GType gxml_gom_enum_get_enum_type (GXmlGomEnum* self) {
	GType result;
	GType _tmp0_ = 0UL;
	g_return_val_if_fail (self != NULL, 0UL);
	_tmp0_ = self->_enum_type;
	result = _tmp0_;
	return result;
}


void gxml_gom_enum_set_enum_type (GXmlGomEnum* self, GType value) {
	GType _tmp0_ = 0UL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	self->_enum_type = _tmp0_;
	g_object_notify ((GObject *) self, "enum-type");
}


static void gxml_gom_enum_class_init (GXmlGomEnumClass * klass) {
	gxml_gom_enum_parent_class = g_type_class_peek_parent (klass);
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_enum_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_enum_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_enum_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_enum_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_enum_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ENUM_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	/**
	   * Enum type used by property.
	   */
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_ENUM_ENUM_TYPE, g_param_spec_gtype ("enum-type", "enum-type", "enum-type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void gxml_gom_enum_instance_init (GXmlGomEnum * self) {
	self->_value = 0;
}


static void gxml_gom_enum_finalize (GObject* obj) {
	GXmlGomEnum * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_ENUM, GXmlGomEnum);
	G_OBJECT_CLASS (gxml_gom_enum_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using a {@link GLib.Type.ENUM} as a source of values.
 *
 * Enumeration is represented as a string, using its name, independent of
 * value possition in enumeration.
 */
GType gxml_gom_enum_get_type (void) {
	static volatile gsize gxml_gom_enum_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_enum_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomEnum), 0, (GInstanceInitFunc) gxml_gom_enum_instance_init, NULL };
		GType gxml_gom_enum_type_id;
		gxml_gom_enum_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomEnum", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_enum_type_id__volatile, gxml_gom_enum_type_id);
	}
	return gxml_gom_enum_type_id__volatile;
}


static void _vala_gxml_gom_enum_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomEnum * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ENUM, GXmlGomEnum);
	switch (property_id) {
		case GXML_GOM_ENUM_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		case GXML_GOM_ENUM_ENUM_TYPE:
		g_value_set_gtype (value, gxml_gom_enum_get_enum_type (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_enum_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomEnum * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_ENUM, GXmlGomEnum);
	switch (property_id) {
		case GXML_GOM_ENUM_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		case GXML_GOM_ENUM_ENUM_TYPE:
		gxml_gom_enum_set_enum_type (self, g_value_get_gtype (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Retrives current value.
   */
void gxml_gom_date_get_date (GXmlGomDate* self, GDate* result) {
	GDate _tmp0_ = {0};
	g_return_if_fail (self != NULL);
	_tmp0_ = self->_value;
	*result = _tmp0_;
	return;
}


/**
   * Sets current value.
   */
void gxml_gom_date_set_date (GXmlGomDate* self, GDate* date) {
	GDate _tmp0_ = {0};
	g_return_if_fail (self != NULL);
	g_return_if_fail (date != NULL);
	_tmp0_ = *date;
	self->_value = _tmp0_;
}


GXmlGomDate* gxml_gom_date_construct (GType object_type) {
	GXmlGomDate * self = NULL;
	self = (GXmlGomDate*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomDate* gxml_gom_date_new (void) {
	return gxml_gom_date_construct (GXML_TYPE_GOM_DATE);
}


static gchar* gxml_gom_date_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomDate* self;
	gboolean _tmp0_ = FALSE;
	gchar* fr = NULL;
	gchar* _tmp1_ = NULL;
	gint fr_length1 = 0;
	gint _fr_size_ = 0;
	gchar* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gchar* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gchar* _tmp4_ = NULL;
	self = (GXmlGomDate*) base;
	_tmp0_ = g_date_valid (&self->_value);
	if (!_tmp0_) {
		result = NULL;
		return result;
	}
	_tmp1_ = g_new0 (gchar, 100);
	fr = _tmp1_;
	fr_length1 = 100;
	_fr_size_ = fr_length1;
	_tmp2_ = fr;
	_tmp2__length1 = fr_length1;
	g_date_strftime (_tmp2_, _tmp2__length1, "%Y-%m-%d", &self->_value);
	_tmp3_ = fr;
	_tmp3__length1 = fr_length1;
	_tmp4_ = g_strdup ((const gchar*) _tmp3_);
	result = _tmp4_;
	fr = (g_free (fr), NULL);
	return result;
}


static void gxml_gom_date_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomDate* self;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	self = (GXmlGomDate*) base;
	memset (&self->_value, 0, sizeof (GDate));
	_tmp0_ = value;
	g_date_set_parse (&self->_value, _tmp0_);
	_tmp1_ = g_date_valid (&self->_value);
	if (!_tmp1_) {
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		_tmp2_ = value;
		_tmp3_ = g_strconcat ("Invalid Date for property: ", _tmp2_, NULL);
		_tmp4_ = _tmp3_;
		_tmp5_ = _ (_tmp4_);
		g_warning ("GomProperty.vala:387: %s", _tmp5_);
		_g_free0 (_tmp4_);
	}
	g_object_notify ((GObject *) self, "value");
}


static void gxml_gom_date_class_init (GXmlGomDateClass * klass) {
	gxml_gom_date_parent_class = g_type_class_peek_parent (klass);
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_date_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_date_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_date_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_date_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_date_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DATE_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_date_instance_init (GXmlGomDate * self) {
	memset (&self->_value, 0, sizeof (GDate));
}


static void gxml_gom_date_finalize (GObject* obj) {
	GXmlGomDate * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_DATE, GXmlGomDate);
	G_OBJECT_CLASS (gxml_gom_date_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using a {@link GLib.Date} as sources of values.
 *
 * Property is represented as a string using a %Y-%m-%d format
 */
GType gxml_gom_date_get_type (void) {
	static volatile gsize gxml_gom_date_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_date_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomDateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_date_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomDate), 0, (GInstanceInitFunc) gxml_gom_date_instance_init, NULL };
		GType gxml_gom_date_type_id;
		gxml_gom_date_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomDate", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_date_type_id__volatile, gxml_gom_date_type_id);
	}
	return gxml_gom_date_type_id__volatile;
}


static void _vala_gxml_gom_date_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomDate * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DATE, GXmlGomDate);
	switch (property_id) {
		case GXML_GOM_DATE_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_date_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomDate * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DATE, GXmlGomDate);
	switch (property_id) {
		case GXML_GOM_DATE_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


/**
   * Retrives current value.
   */
static gpointer _g_date_time_ref0 (gpointer self) {
	return self ? g_date_time_ref (self) : NULL;
}


GDateTime* gxml_gom_date_time_get_datetime (GXmlGomDateTime* self) {
	GDateTime* result = NULL;
	GDateTime* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_value;
	_tmp1_ = _g_date_time_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}


/**
   * Sets current value.
   */
void gxml_gom_date_time_set_datetime (GXmlGomDateTime* self, GDateTime* dt) {
	GDateTime* _tmp0_ = NULL;
	GDateTime* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (dt != NULL);
	_tmp0_ = dt;
	_tmp1_ = _g_date_time_ref0 (_tmp0_);
	_g_date_time_unref0 (self->_value);
	self->_value = _tmp1_;
}


GXmlGomDateTime* gxml_gom_date_time_construct (GType object_type) {
	GXmlGomDateTime * self = NULL;
	self = (GXmlGomDateTime*) gxml_gom_base_property_construct (object_type);
	return self;
}


GXmlGomDateTime* gxml_gom_date_time_new (void) {
	return gxml_gom_date_time_construct (GXML_TYPE_GOM_DATE_TIME);
}


const gchar* gxml_gom_date_time_get_format (GXmlGomDateTime* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_format;
	result = _tmp0_;
	return result;
}


void gxml_gom_date_time_set_format (GXmlGomDateTime* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_if_fail (self != NULL);
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->priv->_format);
	self->priv->_format = _tmp1_;
	g_object_notify ((GObject *) self, "format");
}


static gchar* gxml_gom_date_time_real_get_value (GXmlGomBaseProperty* base) {
	gchar* result;
	GXmlGomDateTime* self;
	GDateTime* _tmp0_ = NULL;
	gchar* s = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GDateTime* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	self = (GXmlGomDateTime*) base;
	_tmp0_ = self->_value;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->priv->_format;
	_tmp2_ = g_strdup (_tmp1_);
	s = _tmp2_;
	_tmp3_ = s;
	if (_tmp3_ == NULL) {
		gchar* _tmp4_ = NULL;
		_tmp4_ = g_strdup ("%FT%T");
		_g_free0 (s);
		s = _tmp4_;
	}
	_tmp5_ = self->_value;
	_tmp6_ = s;
	_tmp7_ = g_date_time_format (_tmp5_, _tmp6_);
	result = _tmp7_;
	_g_free0 (s);
	return result;
}


static void gxml_gom_date_time_real_set_value (GXmlGomBaseProperty* base, const gchar* value) {
	GXmlGomDateTime* self;
	GTimeVal tv = {0};
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	self = (GXmlGomDateTime*) base;
	g_get_current_time (&tv);
	_tmp0_ = value;
	_tmp1_ = g_time_val_from_iso8601 (_tmp0_, &tv);
	if (_tmp1_) {
		GTimeVal _tmp2_ = {0};
		GDateTime* _tmp3_ = NULL;
		_tmp2_ = tv;
		_tmp3_ = g_date_time_new_from_timeval_local (&_tmp2_);
		_g_date_time_unref0 (self->_value);
		self->_value = _tmp3_;
	} else {
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		_tmp4_ = value;
		_tmp5_ = g_strconcat ("Invalid timestamp for property: ", _tmp4_, NULL);
		_tmp6_ = _tmp5_;
		_tmp7_ = _ (_tmp6_);
		g_warning ("GomProperty.vala:426: %s", _tmp7_);
		_g_free0 (_tmp6_);
	}
	g_object_notify ((GObject *) self, "value");
}


static void gxml_gom_date_time_class_init (GXmlGomDateTimeClass * klass) {
	gxml_gom_date_time_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlGomDateTimePrivate));
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->get_value = gxml_gom_date_time_real_get_value;
	GXML_GOM_BASE_PROPERTY_CLASS (klass)->set_value = gxml_gom_date_time_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_date_time_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_date_time_set_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_date_time_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DATE_TIME_FORMAT, g_param_spec_string ("format", "format", "format", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DATE_TIME_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_date_time_instance_init (GXmlGomDateTime * self) {
	self->priv = GXML_GOM_DATE_TIME_GET_PRIVATE (self);
	self->_value = NULL;
}


static void gxml_gom_date_time_finalize (GObject* obj) {
	GXmlGomDateTime * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTime);
	_g_date_time_unref0 (self->_value);
	_g_free0 (self->priv->_format);
	G_OBJECT_CLASS (gxml_gom_date_time_parent_class)->finalize (obj);
}


/**
 * Convenient class to handle {@link GomElement}'s attributes
 * using a {@link GLib.DateTime} as sources of values.
 *
 * Timestamp is considered in local time.
 *
 * Property is represented as a string using a {@link GomDateTime.format}
 * and {@link GLib.DateTime.format} method. If {@link GomDateTime.format}
 * is not set '%FT%T' format is used by default.
 */
GType gxml_gom_date_time_get_type (void) {
	static volatile gsize gxml_gom_date_time_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_date_time_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomDateTimeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_date_time_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomDateTime), 0, (GInstanceInitFunc) gxml_gom_date_time_instance_init, NULL };
		GType gxml_gom_date_time_type_id;
		gxml_gom_date_time_type_id = g_type_register_static (GXML_TYPE_GOM_BASE_PROPERTY, "GXmlGomDateTime", &g_define_type_info, 0);
		g_once_init_leave (&gxml_gom_date_time_type_id__volatile, gxml_gom_date_time_type_id);
	}
	return gxml_gom_date_time_type_id__volatile;
}


static void _vala_gxml_gom_date_time_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomDateTime * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTime);
	switch (property_id) {
		case GXML_GOM_DATE_TIME_FORMAT:
		g_value_set_string (value, gxml_gom_date_time_get_format (self));
		break;
		case GXML_GOM_DATE_TIME_VALUE:
		g_value_take_string (value, gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_date_time_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomDateTime * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DATE_TIME, GXmlGomDateTime);
	switch (property_id) {
		case GXML_GOM_DATE_TIME_FORMAT:
		gxml_gom_date_time_set_format (self, g_value_get_string (value));
		break;
		case GXML_GOM_DATE_TIME_VALUE:
		gxml_gom_base_property_set_value ((GXmlGomBaseProperty*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



